import { Box, Typography } from '@mui/material'
import { useTheme, type Theme } from '@mui/material/styles'
import ControlsButtonGroup from '../ControlsButtonGroup/ControlsButtonGroup'
import type { IMicrophoneAudioTrack, ICameraVideoTrack } from 'agora-rtc-sdk-ng'
import React, { useEffect } from 'react'

interface Props {
  setJoined: (x: boolean) => void
  localCameraTrack: ICameraVideoTrack | null
  localMicrophoneTrack: IMicrophoneAudioTrack | null
  isCaptionEnable: boolean
  setIsCaptionEnable: (value: boolean) => void
}

const ControlCenter = ({
  setJoined,
  localCameraTrack,
  localMicrophoneTrack,
  isCaptionEnable,
  setIsCaptionEnable,
}: Props) => {
  const theme: Theme = useTheme()

  const [currentTime, setCurrentTime] = React.useState(new Date())

  const updateTime = () => {
    setCurrentTime(new Date())
  }

  useEffect(() => {
    const interval = setInterval(updateTime, 6000)
    return () => clearInterval(interval)
  }, [])

  return (
    <Box
      sx={{
        height: '100%',
        width: '100%',
        display: 'flex',
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'center',
      }}
    >
      <Box
        sx={{
          width: '20%',
          paddingLeft: '0px',
          alignItems: 'center',
          justifyContent: 'flex-start',
          textAlign: 'left',
        }}
      >
        <Typography
          sx={{
            fontSize: '18px',
            color: theme.palette.common.white,
            fontWeight: 600,
            textAlign: 'left',
            paddingLeft: '50px',
          }}
        >
          {currentTime.toLocaleTimeString('en-US', {
            hour: '2-digit',
            minute: '2-digit',
            hour12: true,
          })}
        </Typography>
      </Box>
      <Box
        sx={{
          display: 'flex',
          flexDirection: 'row',
          justifyContent: 'center',
          alignItems: 'center',
        }}
      >
        <ControlsButtonGroup
          setJoined={setJoined}
          localCameraTrack={localCameraTrack}
          localMicrophoneTrack={localMicrophoneTrack}
          isCaptionEnable={isCaptionEnable}
          setIsCaptionEnable={setIsCaptionEnable}
        />
      </Box>
      <Box
        sx={{
          width: '20%',
          display: 'flex',
          flexDirection: 'row',
          justifyContent: 'flex-end',
          paddingRight: '20px',
          alignItems: 'center',
        }}
      ></Box>
    </Box>
  )
}

export default ControlCenter
