import React, { useState } from 'react'
import type { IMicrophoneAudioTrack, ICameraVideoTrack } from 'agora-rtc-sdk-ng'
import { Box, IconButton } from '@mui/material'
import MicIcon from '@mui/icons-material/Mic'
import VideocamIcon from '@mui/icons-material/Videocam'
import { useTheme, type Theme } from '@mui/material/styles'
import ClosedCaptionIcon from '@mui/icons-material/ClosedCaption'
import PresentToAllIcon from '@mui/icons-material/PresentToAll'
import MicOffIcon from '@mui/icons-material/MicOff'
import CallEndIcon from '@mui/icons-material/CallEnd'
import VideocamOffIcon from '@mui/icons-material/VideocamOff'

interface Props {
  setJoined: (x: boolean) => void
  localCameraTrack: ICameraVideoTrack | null
  localMicrophoneTrack: IMicrophoneAudioTrack | null
  isCaptionEnable: boolean
  setIsCaptionEnable: (value: boolean) => void
}

const ControlsButtonGroup = ({
  setJoined,
  localCameraTrack,
  localMicrophoneTrack,
  isCaptionEnable,
  setIsCaptionEnable,
}: Props) => {
  const theme: Theme = useTheme()

  const [isAudioEnable, setIsAudioEnable] = useState(localMicrophoneTrack?.enabled)
  const [isVideoEnabled, setIsVideoEnabled] = useState(localCameraTrack?.enabled)
  const [isScreenShared, setIsScreenShared] = useState(false)

  const toogleAudio = async () => {
    if (isAudioEnable) {
      await localMicrophoneTrack?.setEnabled(false)
      setIsAudioEnable(false)
    } else {
      await localMicrophoneTrack?.setEnabled(true)
      setIsAudioEnable(true)
    }
  }

  const toogleVideo = async () => {
    if (isVideoEnabled) {
      await localCameraTrack?.setEnabled(false)
      setIsVideoEnabled(false)
    } else {
      await localCameraTrack?.setEnabled(true)
      setIsVideoEnabled(true)
    }
  }

  const tooogleCaption = () => {
    setIsCaptionEnable(!isCaptionEnable)
  }

  const toogleScreenShare = () => {
    setIsScreenShared(!isScreenShared)
  }

  const handleLeaveCall = () => {
    localCameraTrack?.close()
    localMicrophoneTrack?.close()
    setJoined(false)
  }

  return (
    <Box sx={{ height: '100%', width: '100%' }}>
      <IconButton
        sx={{
          borderRadius: '50%',
          padding: '15px',
          marginX: '15px',
          backgroundColor: isAudioEnable ? 'green' : '#363739',
          '&:hover': { backgroundColor: isAudioEnable ? 'green' : '#363739' },
        }}
        onClick={toogleAudio}
      >
        {isAudioEnable ? (
          <MicIcon sx={{ color: theme.palette.common.white }} />
        ) : (
          <MicOffIcon sx={{ color: theme.palette.common.white }} />
        )}
      </IconButton>
      <IconButton
        sx={{
          borderRadius: '50%',
          padding: '15px',
          marginX: '15px',
          backgroundColor: isVideoEnabled ? 'green' : '#363739',
          '&:hover': { backgroundColor: isVideoEnabled ? 'green' : '#363739' },
        }}
        onClick={toogleVideo}
      >
        {isVideoEnabled ? (
          <VideocamIcon sx={{ color: theme.palette.common.white }} />
        ) : (
          <VideocamOffIcon sx={{ color: theme.palette.common.white }} />
        )}
      </IconButton>
      <IconButton
        sx={{
          borderRadius: '50%',
          padding: '15px',
          marginX: '15px',
          backgroundColor: isCaptionEnable ? '#8ab4f8' : '#363739',
          '&:hover': { backgroundColor: isCaptionEnable ? '#8ab4f8' : '#363739' },
        }}
        onClick={tooogleCaption}
      >
        <ClosedCaptionIcon sx={{ color: isCaptionEnable ? 'black' : theme.palette.common.white }} />
      </IconButton>
      <IconButton
        sx={{
          borderRadius: '50%',
          padding: '15px',
          marginX: '15px',
          backgroundColor: isScreenShared ? 'blue' : '#363739',
          '&:hover': { backgroundColor: isScreenShared ? 'blue' : '#363739' },
        }}
        onClick={toogleScreenShare}
      >
        <PresentToAllIcon sx={{ color: theme.palette.common.white }} />
      </IconButton>
      <IconButton
        sx={{
          borderRadius: '40%',
          padding: '15px',
          paddingX: '25px',
          marginX: '15px',
          backgroundColor: 'red',
          '&:hover': { backgroundColor: 'red' },
        }}
        onClick={handleLeaveCall}
      >
        <CallEndIcon sx={{ color: theme.palette.common.white }} />
      </IconButton>
    </Box>
  )
}

export default ControlsButtonGroup
