import { Box, Button, CircularProgress, Typography } from '@mui/material'
import { useTheme, type Theme } from '@mui/material/styles'

interface Props {
  variant: 'joining' | 'loading' | 'error'
}

const MeetingLoading = ({ variant }: Props) => {
  const theme: Theme = useTheme()

  const renderComponent = (): JSX.Element => {
    switch (variant) {
      case 'joining':
        return (
          <Box
            sx={{
              height: '100%',
              width: '100%',
              display: 'flex',
              justifyContent: 'center',
              alignItems: 'center',
            }}
          >
            <Typography
              variant='h3'
              textAlign={'center'}
              sx={{ fontSize: '18px', color: theme.palette.common.white, fontWeight: '600' }}
            >
              Joining the meeting...
            </Typography>
          </Box>
        )
      case 'loading':
        return (
          <Box
            sx={{
              height: '100%',
              width: '100%',
              display: 'flex',
              justifyContent: 'center',
              alignItems: 'center',
            }}
          >
            <Box
              sx={{
                display: 'flex',
                flexDirection: 'row',
                justifyContent: 'center',
                alignItems: 'center',
              }}
            >
              <CircularProgress
                size={'md'}
                sx={{
                  color: theme.palette.common.white,
                  height: '20px',
                  width: '20px',
                  marginRight: '20px',
                }}
              />
              <Typography
                variant='h3'
                textAlign={'center'}
                sx={{ fontSize: '18px', color: theme.palette.common.white, fontWeight: '600' }}
              >
                Loading devices
              </Typography>
            </Box>
          </Box>
        )
      case 'error':
        return (
          <Box
            sx={{
              height: '100%',
              width: '100%',
              display: 'flex',
              justifyContent: 'center',
              alignItems: 'center',
            }}
          >
            <Box
              sx={{
                backgroundColor: '#262625',
                borderRadius: '20px',
                padding: '20px 40px',
                width: '30%',
                display: 'flex',
                flexDirection: 'column',
                justifyContent: 'center',
                alignItems: 'center',
              }}
            >
              <Typography
                variant='h3'
                textAlign={'center'}
                sx={{
                  fontSize: '18px',
                  color: theme.palette.common.white,
                  fontWeight: '600',
                  marginTop: '10px',
                }}
              >
                Unexpected error occurred. Please try reloading the page. 😞
              </Typography>
              <Button
                variant='text'
                sx={{
                  color: theme.palette.primary.main,
                  borderRadius: '10px',
                  padding: '10px 20px',
                  marginTop: '10px',
                  fontWeight: '600',
                }}
                onClick={() => window.location.reload()}
              >
                Reload
              </Button>
            </Box>
          </Box>
        )
      default:
        return <></>
    }
  }

  return renderComponent()
}

export default MeetingLoading
