import React, { useEffect, useState } from 'react'
import { Box, Grid } from '@mui/material'
import useMediaQuery from '@mui/material/useMediaQuery'
import { useRemoteUsers } from 'agora-rtc-react'
import { useTheme, type Theme } from '@mui/material/styles'
import type { IAgoraRTCRemoteUser, ICameraVideoTrack } from 'agora-rtc-sdk-ng'
import UserCard from '../UserCard/UserCard'

interface Props {
  totalUsers: number
  gridContainerHeight: number
  isPinned: boolean
  setIsPinned: (value: boolean) => void
  setPinnedUser: (value: IAgoraRTCRemoteUser | null) => void
  localCameraTrack: ICameraVideoTrack | null
}

const SymmetricGrid = ({
  totalUsers,
  gridContainerHeight,
  isPinned,
  setIsPinned,
  setPinnedUser,
  localCameraTrack,
}: Props) => {
  const theme: Theme = useTheme()
  const isSm = useMediaQuery(theme.breakpoints.up('sm'))
  const isMd = useMediaQuery(theme.breakpoints.up('md'))
  const isLg = useMediaQuery(theme.breakpoints.up('lg'))

  const remoteUsers = useRemoteUsers()

  const [itemOffset, setItemOffset] = useState(12)
  const [itemHeight, setItemHeight] = useState(230)
  const [numOfItems, setNumOfItems] = useState(1)

  const maxUsersDisplay = isLg ? 12 : isMd ? 9 : isSm ? 4 : 2

  useEffect(() => {
    setNumOfItems(totalUsers > maxUsersDisplay ? maxUsersDisplay : totalUsers)
  }, [totalUsers])

  useEffect(() => {
    switch (numOfItems) {
      case 1:
        setItemOffset(12)
        setItemHeight(gridContainerHeight)
        break
      case 2:
        setItemOffset(isSm ? 6 : 12)
        setItemHeight(isSm ? gridContainerHeight : (gridContainerHeight - 16) / 2)
        break
      case 3:
        setItemOffset(isMd ? 4 : isSm ? 6 : 12)
        setItemHeight(
          isMd
            ? gridContainerHeight
            : isSm
              ? (gridContainerHeight - 16) / 2
              : (gridContainerHeight - 32) / 3,
        )
        break
      case 4:
        setItemOffset(isSm ? 6 : 12)
        setItemHeight(isSm ? (gridContainerHeight - 16) / 2 : (gridContainerHeight - 16 * 3) / 4)
        break
      case 5:
        setItemOffset(isMd ? 4 : isSm ? 6 : 12)
        setItemHeight(
          isMd
            ? (gridContainerHeight - 16) / 2
            : isSm
              ? (gridContainerHeight - 16 * 2) / 3
              : (gridContainerHeight - 32 * 4) / 5,
        )
        break
      case 6:
        setItemOffset(isMd ? 4 : isSm ? 6 : 12)
        setItemHeight(
          isMd
            ? (gridContainerHeight - 16) / 2
            : isSm
              ? (gridContainerHeight - 16 * 2) / 3
              : (gridContainerHeight - 32 * 5) / 6,
        )
        break
      case 7:
        setItemOffset(isLg ? 3 : isMd ? 4 : isSm ? 6 : 12)
        setItemHeight(
          isLg
            ? (gridContainerHeight - 16) / 2
            : isMd
              ? (gridContainerHeight - 16 * 2) / 3
              : isSm
                ? (gridContainerHeight - 16 * 3) / 4
                : (gridContainerHeight - 32 * 6) / 7,
        )
        break
      case 8:
        setItemOffset(isLg ? 3 : isMd ? 4 : isSm ? 6 : 12)
        setItemHeight(
          isLg
            ? (gridContainerHeight - 16) / 2
            : isMd
              ? (gridContainerHeight - 16 * 2) / 3
              : isSm
                ? (gridContainerHeight - 16 * 3) / 4
                : (gridContainerHeight - 32 * 7) / 8,
        )
        break
      case 9:
        setItemOffset(isMd ? 4 : isSm ? 6 : 12)
        setItemHeight(
          isMd
            ? (gridContainerHeight - 16 * 2) / 3
            : isSm
              ? (gridContainerHeight - 16 * 4) / 5
              : (gridContainerHeight - 32 * 8) / 9,
        )
        break
      default:
        setItemOffset(isLg ? 3 : isMd ? 4 : isSm ? 6 : 12)
        setItemHeight(
          isLg ? (gridContainerHeight - 16 * 2) / 3 : (gridContainerHeight - 16 * 3) / 4,
        )
    }
  }, [totalUsers, isSm, isMd, isLg, gridContainerHeight, numOfItems])

  return (
    <Box sx={{ display: 'flex', width: '100%' }}>
      <Grid container spacing={3} width={'100%'} padding={0}>
        <Grid item xs={itemOffset}>
          <UserCard
            type={'local'}
            itemHeight={itemHeight}
            setIsPinned={setIsPinned}
            setPinnedUser={setPinnedUser}
            localCameraTrack={localCameraTrack}
          />
        </Grid>
        {remoteUsers.map((remoteUser, index) => (
          <Grid item xs={itemOffset} key={index}>
            <UserCard
              type={'remote'}
              remoteUser={remoteUser}
              itemHeight={itemHeight}
              setIsPinned={setIsPinned}
              setPinnedUser={setPinnedUser}
            />
          </Grid>
        ))}
      </Grid>
    </Box>
  )
}

export default SymmetricGrid
